**Example 1: 删除主题**



Input: 

```
tccli ckafka DeleteDatahubTopic --cli-unfold-argument  \
    --Name 12345-test
```

Output: 
```
{
    "Response": {
        "Result": {
            "ReturnMessage": "xx",
            "ReturnCode": "xx",
            "Data": {
                "FlowId": 0
            }
        },
        "RequestId": "xx"
    }
}
```

